var indexSectionsWithContent =
{
  0: "abcdfhlmnoprstuvw",
  1: "cfl",
  2: "abcdflmnoprstvw",
  3: "acdfln",
  4: "dhlnp",
  5: "aclsu",
  6: "a",
  7: "a",
  8: "ah",
  9: "a"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "files",
  3: "functions",
  4: "variables",
  5: "typedefs",
  6: "enums",
  7: "enumvalues",
  8: "defines",
  9: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Data Structures",
  2: "Files",
  3: "Functions",
  4: "Variables",
  5: "Typedefs",
  6: "Enumerations",
  7: "Enumerator",
  8: "Macros",
  9: "Pages"
};

